--[[
 This file is part of DungeonTime.

    DungeonTime is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DungeonTime is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DungeonTime.  If not, see <http://www.gnu.org/licenses/>.
]]

DungeonTime = LibStub("AceAddon-3.0"):NewAddon("DungeonTime", "AceEvent-3.0", "AceConsole-3.0");
local L = LibStub("AceLocale-3.0"):GetLocale("DungeonTime");

-- On init
function DungeonTime:OnInitialize()
	self:RegisterChatCommand("dt", "ChatCommand");
end;

-- On enable
function DungeonTime:OnEnable()
	self:RegisterEvent("LFG_PROPOSAL_SHOW", "LFGWarning");
end;

-- Chat Command
function DungeonTime:ChatCommand(input)
	self:Run()
end;

function DungeonTime:Run()
	local isLeader, isTank, isHealer, isDPS = GetLFGRoles();
	local waitTime;
	local hasData, leaderNeeds, tankNeeds, healerNeeds, dpsNeeds, instanceType, instanceName, averageWait, tankWait, healerWait, damageWait, myWait, queuedTime = GetLFGQueueStats();
	if hasData then
		if isTank and tankWait ~= nil then
			self:Print(L["Tank Wait: "]..self:FormatTime(tankWait));
		end;
		if isHealer and healerWait ~= nil then
			self:Print(L["Heal wait: "]..self:FormatTime(healerWait));
		end;
		if isDPS and damageWait ~= nil then
			self:Print(L["DPS wait: "]..self:FormatTime(damageWait));
		end;
		self:Print(L["Average wait: "]..self:FormatTime(averageWait));
		self:Print(L["Predicted wait: "]..self:FormatTime(myWait));
		waitTime = GetTime() - queuedTime;
		self:Print(L["Time on queue: "]..self:FormatTime(waitTime));
	else
		self:Print(L["You're not queued or no data available yet!"]);
	end;
end;

function DungeonTime:FormatTime(timer)
	local seconds, minutes;
	if timer ~= -1 then
		minutes = tonumber(string.format("%." .. (0) .. "f", timer/60));
		seconds = timer % 60;
		if seconds < 10 then
			seconds = "0"..seconds;
		end;
		return(minutes..":"..seconds);
	else
		return("N/A");
	end;
end;

function DungeonTime:LFGWarning()
	PlaySoundFile("Interface\\AddOns\\DungeonTime\\warning.ogg");
end;
